
//***********************************************************************************************************************
// Unit StringUtils
// String Utility Routines
// Author M.C.Brooks (C) 1996
//***********************************************************************************************************************

unit StrUtils;

interface

{$A+}

function  SUEncrypt(const S: string): string;
function  SUDecrypt(const S: string): string;
function  SURemoveStar(const S: string): string;
function  SUProperCase(const S: string): string;
function  SULeadingCase(const S: string): string;
function  SUAddBackSlash(const S: string): string;
function  SURemoveBackSlash(const S: string): string;
procedure SUBreakupFullName(const S: string; var Surname: string; var Firstname: string; var Initials: string);
procedure SUMakeFullName(var S: string; const Surname: string; const Firstname: string; const Initials: string);

implementation

uses
  SysUtils;

//***********************************************************************************************************************
// SUEncrypt
//***********************************************************************************************************************

function SUEncrypt(const S: string): string;
var
  I: integer;
begin
  SetLength(Result,Length(S));
  for I := 1 to Length(S) do begin
    Result[I] := succ(S[I]);
  end;
end;

//***********************************************************************************************************************
// SUDecrypt
//***********************************************************************************************************************

function SUDecrypt(const S: string): string;
var
  I: integer;
begin
  SetLength(Result,Length(S));
  for I := 1 to Length(S) do begin
    Result[I] := pred(S[I]);
  end;
end;

//**********************************************************************************************************************
// SUProperCase
// Accepts a string and returns its proper case equivalent trimmed of leading and trailing spaces
//**********************************************************************************************************************

function SUProperCase(const S: string): string;
var
  I: integer;
begin
  Result := LowerCase(Trim(S));
  for I := 1 to Length(Result) do
    if (I = 1) or (Result[I - 1] in ['-',' ',',','.','\']) then
      Result[I] := UpCase(Result[I]);
end;

//**********************************************************************************************************************
// SULeadingCase
// Accepts a string and returns its leading case equivalent trimmed of leading and trailing spaces
//**********************************************************************************************************************

function SULeadingCase(const S: string): string;
begin
  Result := LowerCase(Trim(S));
  if Length(Result) > 0 then
    Result[1] := UpCase(Result[1]);
end;

//**********************************************************************************************************************
// SUAddBackSlash
// Accepts a string and returns its equivalent but with a training backslash if there wasn't one
//**********************************************************************************************************************

function SUAddBackSlash(const S: string): string;
begin
  Result := S;
  if Copy(Result,Length(Result),1) <> '\' then
    Result := Result + '\';
end;

//**********************************************************************************************************************
// SURemoveBackSlash
// Accepts a string and returns its equivalent but without a trailing backslash if there was one
//**********************************************************************************************************************

function SURemoveBackSlash(const S: string): string;
begin
  Result := S;
  if Copy(Result,Length(Result),1) = '\' then
    Result := Copy(Result,1,Length(Result) - 1);
end;

//**********************************************************************************************************************
// SURemoveStar
// Accepts a string and returns its equivalent but without a trailing star if there was one
//**********************************************************************************************************************

function SURemoveStar(const S: string): string;
begin
  Result := S;
  if Copy(Result,Length(Result),1) = '*' then
    Result := Copy(Result,1,Length(Result) - 1);
end;

//**********************************************************************************************************************
// SUBreakupFullName
// Breaks up a name of the form Surname, Firstname Initials into its constituent parts
//**********************************************************************************************************************

procedure SUBreakupFullName(const S: string; var Surname: string; var Firstname: string; var Initials: string);
var
  T: PChar;
  Ptr: PChar;
begin

  // Allocate a PChar to hold S

  GetMem(T,Length(S) + 1);
  if T = nil then
    Exit;

  // Set the PChar up

  StrPCopy(T,Trim(S));
  Ptr := T;

  // Extract from the PChar into Surname

  Surname := '';
  while Ptr^ <> #0 do
    begin
      if (Ptr^ = #32) or (Ptr^ = ',') then
        Break;
      Surname := Surname + Ptr^;
      Inc(Ptr);
    end;
  Surname := SUProperCase(Surname);

  // Find the start of Firstname

  while Ptr^ <> #0 do
    begin
      if (Ptr^ <> #32) and (Ptr^ <> ',') then
        Break;
      Inc(Ptr);
    end;

  // Extract from the PChar into Firstname

  Firstname := '';
  while Ptr^ <> #0 do
    begin
      if (Ptr^ = #32) or (Ptr^ = ',') then
        Break;
      Firstname := Firstname + Ptr^;
      Inc(Ptr);
    end;
  Firstname := SUProperCase(Firstname);

  // Find the start of Initials

  while Ptr^ <> #0 do
    begin
      if (Ptr^ <> #32) and (Ptr^ <> ',') then
        Break;
      Inc(Ptr);
    end;

  // Extract from the PChar into Initials

  Initials := '';
  while Ptr^ <> #0 do
    begin
      if (Ptr^ = #32) or (Ptr^ = ',') then
        Break;
      Initials := Initials + Ptr^;
      Inc(Ptr);
    end;
  Initials := UpperCase(Initials);

  // Free the pchar

  FreeMem(T,Length(S) + 1);
end;

//**********************************************************************************************************************
// SUMakeFullName
// Creates a name of the form Surname, Firstname Initials from its constituent parts
//**********************************************************************************************************************

procedure SUMakeFullName(var S: string; const Surname: string; const Firstname: string; const Initials: string);
begin
  S := '';

  if Trim(Surname) <> '' then
    S := S + SUProperCase(Surname);

  if Trim(Firstname) <> '' then
    begin
      if S <> '' then
        S := S + ', ';
      S := S + SUProperCase(Firstname);
    end;

  if Trim(Initials) <> '' then
    begin
      if S <> '' then
        S := S + ' ';
      S := S + UpperCase(Trim(Initials));
    end;
end;

end.
